import socket
import uuid

class DeviceConfiguration:
    def __init__(self):
        self.originalValues = {}
        self.hideIpAddress = True
        self.hideMacAddress = True
        self.hideBluetoothAddress = True
        self.setHostname = "127.0.0.1"
        self.hideAllDeviceInfo = True
        self.hideAllUserIdentity = True

    def set_hide_ip_address(self, hide_ip_address):
        self.hideIpAddress = hide_ip_address
        if hide_ip_address:
            self.originalValues["ipAddress"] = self.get_ip_address()
            self.set_ip_address("127.0.0.1")
        elif "ipAddress" in self.originalValues:
            self.set_ip_address(self.originalValues["ipAddress"])
            del self.originalValues["ipAddress"]

    def is_hide_ip_address(self):
        return self.hideIpAddress

    def set_hide_mac_address(self, hide_mac_address):
        self.hideMacAddress = hide_mac_address
        if hide_mac_address:
            self.originalValues["macAddress"] = self.get_mac_address()
            self.set_mac_address("00:00:00:00:00:00")
        elif "macAddress" in self.originalValues:
            self.set_mac_address(self.originalValues["macAddress"])
            del self.originalValues["macAddress"]

    def is_hide_mac_address(self):
        return self.hideMacAddress

    def set_hide_bluetooth_address(self, hide_bluetooth_address):
        self.hideBluetoothAddress = hide_bluetooth_address
        if hide_bluetooth_address:
            self.originalValues["bluetoothAddress"] = self.get_bluetooth_address()
            self.set_bluetooth_address("00:00:00:00:00:00")
        elif "bluetoothAddress" in self.originalValues:
            self.set_bluetooth_address(self.originalValues["bluetoothAddress"])
            del self.originalValues["bluetoothAddress"]

    def is_hide_bluetooth_address(self):
        return self.hideBluetoothAddress

    def set_set_hostname(self, set_hostname):
        self.setHostname = set_hostname

    def get_set_hostname(self):
        return self.setHostname

    def set_hide_all_device_info(self, hide_all_device_info):
        self.hideAllDeviceInfo = hide_all_device_info
        if hide_all_device_info:
            self.set_hide_ip_address(True)
            self.set_hide_mac_address(True)
            self.set_hide_bluetooth_address(True)
        else:
            self.set_hide_ip_address(False)
            self.set_hide_mac_address(False)
            self.set_hide_bluetooth_address(False)

    def is_hide_all_device_info(self):
        return self.hideAllDeviceInfo

    def set_hide_all_user_identity(self, hide_all_user_identity):
        self.hideAllUserIdentity = hide_all_user_identity
        if hide_all_user_identity:
            # Hide all user identity info (implement logic)
            pass
        else:
            # Restore all user identity info (implement logic)
            pass

    def is_hide_all_user_identity(self):
        return self.hideAllUserIdentity

    def get_ip_address(self):
        if self.hideIpAddress:
            return "Hidden"
        else:
            try:
                return socket.gethostbyname(socket.gethostname())
            except:
                return "Unknown"

    def set_ip_address(self, value):
        self.setHostname = value

    def get_mac_address(self):
        if self.hideMacAddress:
            return "Hidden"
        else:
            try:
                return ':'.join(['{:02x}'.format((uuid.getnode() >> elements) & 0xff) for elements in range(0,2*6,2)][::-1])
            except:
                return "Unknown"

    def set_mac_address(self, value):
        # Setting MAC address is typically not supported, so we leave this method empty.
        pass

    def get_bluetooth_address(self):
        if self.hideBluetoothAddress:
            return "Hidden"
        else:
            try:
                return ':'.join(['{:02x}'.format((uuid.getnode() >> elements) & 0xff) for elements in range(0,2*6,2)])
            except:
                return "Unknown"

    def set_bluetooth_address(self, value):
        # Setting Bluetooth address is typically not supported, so we leave this method empty.
        pass
